.. _how-to-contribute:

How to Contribute to Eventlet
#############################

.. include:: asyncio/warning.rst

Contribution are welcome. 

You want to report something? Read :ref:`report-a-bug`.

You want to propose changes? Read :ref:`propose-changes`.

.. _report-a-bug:

Report a Bug
=============

You find a bug and you want to report it?

You simply have to `create a new github issue <https://github.com/eventlet/eventlet/issues>`_ 
where you describe your problem.

Do not forget to provide technical details like:

* the hub you use
* the context of your bug
* the error message you get
* everything else that may help us to understand your problem.

The more you give details, the more we will be able to help you.

.. _propose-changes:

Propose Changes
===============

You may want to propose changes to fix a bug, improve the documentation, etc.

Feel free to open a pull request: https://github.com/eventlet/eventlet/pulls

.. include:: asyncio/warning.rst

We will be happy to review it.

At this point you may be also interested by :ref:`how to test Eventlet <testing-eventlet>`.
